.. include:: ../README.rst

.. toctree::
   :maxdepth: 3
   :hidden:

   readme
   quickstart
   installation
   concepts
   api
   tutorial
   design
   cli
   externals
   faq
   backends
   contributingindex
   authors
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
